hotspot/src/share/vm/gc/g1/heapRegion.hpp
changeset 34249 a015a11067a2
parent 33786 ac8da6513351
child 34617 943740ea0d17
--- a/hotspot/src/share/vm/gc/g1/heapRegion.hpp	Fri Sep 11 15:18:43 2015 +0200
+++ b/hotspot/src/share/vm/gc/g1/heapRegion.hpp	Fri Nov 20 17:32:02 2015 +0100
@@ -455,9 +455,9 @@
   // the first region in a series of one or more contiguous regions
   // that will contain a single "humongous" object.
   //
-  // obj_top : points to the end of the humongous object that's being
-  // allocated.
-  void set_starts_humongous(HeapWord* obj_top);
+  // obj_top : points to the top of the humongous object.
+  // fill_size : size of the filler object at the end of the region series.
+  void set_starts_humongous(HeapWord* obj_top, size_t fill_size);
 
   // Makes the current region be a "continues humongous'
   // region. first_hr is the "start humongous" region of the series